<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Integrations Documentation

- **[linear-erk-mapping.md](linear-erk-mapping.md)** — Evaluating Linear as issue tracker for erk, Building Linear gateway, Understanding trade-offs between GitHub Issues and Linear
- **[linear-primitives.md](linear-primitives.md)** — Considering Linear as an alternative to GitHub Issues, Building a Linear gateway for erk, Understanding how other tools (Cursor, Devin) integrate with Linear
